#
# spec file for package hydrogen
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with lash
# The use of librubberband2 is marked as experimental.
# Because the current implementation produce wrong timing!
# So long this bug isn't solved, please disable this option.
# If rubberband-cli is installed, the hydrogen rubberband-function
# will work properly as expected.
%bcond_with librubberband
Name:           hydrogen
Version:        1.2.4
%define soversion 1_2_4
Release:        1.2
Summary:        A Real-Time Drum Machine and Sequencer
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Midi
URL:            http://www.hydrogen-music.org/
Source0:        https://github.com/hydrogen-music/hydrogen/archive/%{version}/%{name}-%{version}.tar.gz
Patch2:         release-version.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  help2man
BuildRequires:  hicolor-icon-theme
BuildRequires:  ladspa
BuildRequires:  ladspa-devel
BuildRequires:  libtar-devel
BuildRequires:  pkgconfig
BuildRequires:  portmidi-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Core) >= 5.6
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  cmake(Qt5Sql)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  cmake(Qt5XmlPatterns)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(liblo)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(lrdf)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(raptor2)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} <= 1500
BuildRequires:  gcc9
BuildRequires:  gcc9-c++
%else
BuildRequires:  gcc-c++
%endif
%if %{with lash}
BuildRequires:  pkgconfig(lash-1.0)
%endif
%if %{with librubberband}
BuildRequires:  pkgconfig(rubberband)
%else
BuildRequires:  rubberband-cli
Requires:       rubberband-cli
%endif

%description
Hydrogen is a software synthesizer which can be used alone, emulating
a drum machine based on patterns, or via an external MIDI
keyboard/sequencer software.

It features a modular and graphical interface based on QT5, has a
sample-based stereo audio engine, with import of sound samples in PCM
formats. Furthermore, a pattern-based sequencer with the ability to
chain patterns into a song. Up to 64 ticks per pattern with
individual level per event and variable pattern length are possible.
32 instrument tracks with volume, mute, solo, pan capabilities are
provided, and there is multi-layer support for instruments (up to 16
samples for each instrument). Human velocity, human time, pitch and
swing functions are implemented as well.

%package -n libhydrogen-core-%{soversion}
Summary:        Library essential for the hydrogen drum machine software
Group:          System/Libraries

%description -n libhydrogen-core-%{soversion}
Hydrogen is a software synthesizer which can be used alone, emulating
a drum machine based on patterns, or via an external MIDI
keyboard/sequencer software.

This library is the core of hydrogen's operation.

%package -n libhydrogen-core-devel
BuildArch:      noarch
Summary:        Development files and headers for libhydrogen-core
Group:          Development/Libraries/C and C++
Requires:       libhydrogen-core-%{soversion} = %{version}

%description -n libhydrogen-core-devel
These are the headers needed to develop apps that
link with libhydrogen-core.

%prep
%autosetup -p1

%build
export LADSPA_PATH=%{_libdir}/ladspa

%cmake \
%if 0%{?suse_version} <= 1500
	-DCMAKE_C_COMPILER=gcc-9 \
	-DCMAKE_CXX_COMPILER=g++-9 \
%endif
%if %{with lash}
	-DWANT_LASH:BOOL=ON \
%endif
	-DWANT_LIBARCHIVE:BOOL=ON \
	-DWANT_LRDF:BOOL=ON \
	-DWANT_PORTAUDIO:BOOL=ON \
	-DWANT_PORTMIDI:BOOL=ON \
%if %{with librubberband}
	-DWANT_RUBBERBAND:BOOL=ON \
%endif
	-DWANT_SHARED:BOOL=ON

%cmake_build

%install
%cmake_install

# Install the h2cli man page created by help2man
install -d -m 0755 %{buildroot}%{_mandir}/man1
LD_LIBRARY_PATH=%{buildroot}%{_libdir} \
	help2man -N -o %{buildroot}%{_mandir}/man1/h2cli.1 %{buildroot}%{_bindir}/h2cli

%suse_update_desktop_file -i org.hydrogenmusic.Hydrogen AudioVideo Sequencer

%fdupes -s %{buildroot}%{_datadir}

%find_lang %{name} --with-qt

%files -f %{name}.lang
%license COPYING
%doc AUTHORS ChangeLog README.md
%{_bindir}/*
%{_datadir}/%{name}
%{_datadir}/applications/org.hydrogenmusic.Hydrogen.desktop
%{_datadir}/icons/hicolor/scalable/apps/*.svg
%{_datadir}/metainfo/org.hydrogenmusic.Hydrogen.metainfo.xml
%{_mandir}/man1/h2cli.1%{?ext_man}
%{_mandir}/man1/hydrogen.1%{?ext_man}

%files -n libhydrogen-core-%{soversion}
%{_libdir}/libhydrogen-core-%{version}.so

%files -n libhydrogen-core-devel
%{_includedir}/%{name}

%changelog
* Tue Dec 17 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to version 1.2.4
  This patch release fixes a number of bugs and inconsistencies found
  since version 1.2.3 and is generally recommended for all users.
  Added
  * Forward compatibility for .h2song, .h2pattern, .h2playlist, and
    drumkit changes introduced in version 2.0.
  * MIDI and OSC commands
  * CLEAR_SELECTED_INSTRUMENT - to remove all notes of the selected
    pattern associated with the currently selected instrument.
  * CLEAR_PATTERN - to remove all notes of the selected pattern.
  * INSTRUMENT_PITCH - to adjust the pitch of an instrument.
  * OSC commands
  * NOTE_ON and NOTE_OFF which are handled like incoming MIDI events
    without triggering their associated actions.
  * CLEAR_INSTRUMENT - to remove all notes of the selected pattern
    associated with the provided instrument number.
  * CLI option:
  * -O/--osc-port to use a custom OSC port in both hydrogen and h2cli.
  * -L/--log-file to provide a path to an alternative log file.
  * -T/--log-timestamps to add timestamps to all log messages.
  * --config to use a different user-level config file.
  * --compression-level for h2cli to set the trade-off between
    max. quality (.mp3 and .ogg)/max. speed (.flac) (0.0) and
    max. compression (1.0) for exported audio files.
  * Adding support for importing and exporting audio files of
    format .mp3, .opus, .au, .caf, .voc, .w64. Drumkits containing
    those formats can be loaded with older versions of Hydrogen too.
    libsndfile >= 1.1.0 is required on your system for MP3 support. (#2023)
  * X-NSM-Exec entry added to org.hydrogenmusic.Hydrogen.desktop
    by @grammoboy2 (#2042).
  * Delete key does now remove selected notes and notes under
    cursor in NotePropertiesRuler.
  Changed
  * Brazilian translation updated.
  * Grid lines in the Song Editor are now rendered dotted to
    emphasize that this is the space the patterns in rather
    than objects in their own right.
  * Virtual keyboard strokes are now mapped exactly as incoming
    MIDI NOTE_ON events (respecting both "Use output note as input note"
    and hihat pressure groups). But do not trigger associated actions (#1770).
  * CLI option -d understand driver names regardless of capitalization.
  * h2cli option -V is now able to handle whitespaces between flag and argument.
  * h2cli long option for -k is renamed --drumkit -> kit in order to
    align the naming with the one used in hydrogen CLI options.
  * Smaller keyboard cursor size with resolution set to off.
  * Rename "J.Master" button into "Timebase".
  Fixed
  * Fix potential segfault on ill-formated notes in .h2song files.
  * Fix buzzing sound during startup when using Port Audio (#1932).
  * Fix build failure without precompiled headers (e.g. on Gentoo) (#1944).
  * Fix persistent of hihat pressure group settings while
    changing/restarting MIDI drivers.
  * Fix mapping of NOTE_OFF MIDI messages in hihat pressure groups.
  * Fix segfault when using MIDI sense button in table of
    Preferences > MIDI after removing rows above it from the table.
  * Fix synchronization problems while using JACK Timebase support (#1953).
  * Fix compilation error on macOS with case-sensitive filesystem (#1938).
  * Fix usability with large QT_SCALE_FACTOR (#1933).
  * Fix MIDI, WAV, and LilyPond export as well as drumkit import
    and export with with non-ASCII filenames (#1957).
  * Paths to songs and scripts are now properly saved relative to
    a .h2playlist file (in case the corresponding option was set).
  * Fix grid line rendering with resolution set to off (#2015).
  * Fix handling of adjacent tags with same content in Director by @aldimond (#2036).
  * Fix copy/cut/paste in PianoRollEditor.
  Removed
  * Windows 32bit support dropped (due to upstream limitations).
* Sat Jan 13 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to version 1.2.3
- Remove Fix-driver-switching-whil-using-JACK.patch and
  Fix-JACK-support.patch now upstream
- Refresh release-version.patch
  Added
  * Forward compatibility for .h2song and drumkit changes introduced
    in version 1.3.0
  Fixed
  * Restore mute button state of master mixer strip on song load.
  * Recorded MIDI notes were inserted ahead of the beat (#1851).
  * Drumkit Property Dialog:
  * Images were written regardless whether one hits the ok or cancel button.
  * When using Save As to create a new drumkit, the added image was put in the
    old drumkit folder instead and not properly copied into the new one.
  * Allow to Save As drumkits derived from kits not found on the current system.
  * Audio Engine: In Song Mode with Loop Mode deactivated Hydrogen missed notes
    very close to the end of the song.
  * Fix crash on playing back notes with custom length (#1852).
  * macOS: fix naming of CoreMIDI header (#1865).
  * Fix various rendering issues with custom length notes.
  * Fix potential crash/failing startup on Windows in case PortAudio or PortMidi
    device is already occupied (#1893)
  * Fix crash on shutdown, song export, or driver changes in the Preferences while
    using JACK on Linux (#1902, #1867, #1907)
  * Pattern Editor:
  * Only delete stop notes clicked by the user. (#1859)
  * Proper undo of moving notes out of DrumPatternEditor. (#1859)
  * Custom note lengths are now only drawn till the next stop
    note. (#1859)
  * Highlight selected stop notes too. (#1859)
  * Update selected notes visually on left and right keyboard movement. (#1859)
  * Fixed stop note color which was no different than the default note color
    (#1854).
  * Fixed grid line rendering on rational pattern size nominator.
  * Fixed grid line colors on very fine resolution.
  * Fix broken file browser dialogs on Linux when using translations (#1908).
  * Fix drumkit export on Windows (#1927).
  * Timing drift (and artifacts) in playback track rendering on some hosts is
    fixed (#1920).
* Thu Jan  4 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- Add Fix-driver-switching-whil-using-JACK.patch and
    Fix-JACK-support.patch which fixes crashes
* Wed Jan  3 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- Remove fix-obsolete-appdata.patch now upstream
- Set noarch for libhydrogen-core-devel package
- Update to version 1.2.2
  Added
  * Hydrogen is now released as AppImage for Linux as well.
  * Playlist dialog can now be resized and remembers geometry,
    position, as well as visibility.
  * Save and restore Director position, geometry, and visibility.
  * New and properly licensed AppStream metainfo files
    org.hydrogenmusic.Hydrogen.metainfo.xml replace old
    org.hydrogenmusic.Hydrogen.appdata.xml.
  * Hydrogen shows an error dialog and exits on the first invocation
    with no hydrogen.conf file present on user and system level
    (application was not properly installed).
  * A new cmake option WANT_DYNAMIC_JACK_CHECK was
    introduced. When set Hydrogen does check on startup whether
    jackd, jackdbus, or pw-jack is installed and disables JACK
    support in case none of them was found. This is intended for
    bundled builds, like AppImage and Flatpak, and can be overridden
    by setting the audio driver manually to "Jack" in the
    hydrogen.conf or by passing the "-d jack" CLI option.
  Changed
  * Spanish translation updated.
  * Minor tweaks in French and German translation.
  * On Linux the order of audio drivers tried when selecting Auto
    changed from "JACK > ALSA > OSS > PulseAudio" to
    "JACK > PulseAudio > ALSA > OSS".
  Fixed
  * Style combo box in Preferences > Appearance > Interface is
    working again.
  * Fix segfault on hitting "Panic" button while transport was
    rolling.
  * Instrument/strip-specific actions, like MIDI action
    STRIP_MUTE_TOGGLE, did void the instrument selection of the
    Instrument Editor if the specified instrument was not the
    currently selected one.
  * Do not start playback at cursor when cursor in Song Editor is
    beyond the current song length.
  * Fixed compatibility with PortMidi version 217 (Hydrogen v1.2.1
    was incompatible) (#1795). All versions of Hydrogen >=1.3 will,
    however, require on a more recent PortMidi version (at least
    v2.0.1).
  * Fixed allowed range of MIDI output notes to be [0,127] again
    (#1828) (introduced in v1.2.0).
  * Hydrogen does now successfully startup even if no data folder is
    present on user and system level.
  * Allow an arbitrary number of notes in a pattern (#1827).
  * Fix playback track volume fader (#1449)
* Sun Jun 11 2023 Konstantin Voinov <kv@kott.no-ip.biz>
  * Update to version 1.2.1
  * Remove hydrogen-Fix-beat-and-bar-calculation-in-pattern-mode.patch
  now upstream
  * Update patch release-version.patch
  * Update French translation
  * Bugfixes
  - Fix reopening of last used Playlist. In addition, in case the
    PlaylistDialog was opened at the end of the last session - when
    "Reopen last used playlist" is checked in the Preferences - the
    dialog will be reopened too at the same position.
  - Fix spurious marking of opened songs as modified.
  - Fix MIDI (output) feedback for metronome toggling and pan
    setting.
  - Fix superfluous MIDI event - Action bindings. An incoming MIDI
    event can be mapped to an Action only once.
  - Fix tool tips of MIDI-learnable widgets. All bounded MIDI events
    will be shown.
  - Fix MIDI note output for channel 16 (previously only channel
    1-15 were accessible in the InstrumentEditor).
  - Fix spurious tempo changes to 120bpm when switching songs or
    between pattern and song mode (#1779 and #1785)
  - Support "START", "CONTINUE", and "STOP" type System Realtime
    MIDI messages in PortMidi and CoreMidi.
  - Fix MIDI action binding to incoming MMC_DEFERRED_PLAY event.
  - Fix missing MIDI driver restart when adjusting corresponding
    parameters in Preferences.
  - Fix MIDI Machine Control (MMC) event type handling on Windows
    (#1773)
  - Fix loading of legacy drumkits. All layers but the first one
    were dropped during drumkit upgrade (#1759)
  - Fix MIDI input handling with "Discard MIDI messages after action
    has been triggered" checked. Incoming NOTEON message were
    dropped without triggering a sound (#1751)
  - Fix beat and bar calculation in pattern mode (#1741)
  - Fix compilation in GCC with -Werror=format-security (#1739)
  - Explicit usage of Python3 in stats.py script
  - Fix build against Musl (nekopsykose)
  - Omit git commit hash in displayed version of release builds
* Tue Apr 25 2023 Konstantin Voinov <kv@kott.no-ip.biz>
- Add upstream patch:
  hydrogen-Fix-beat-and-bar-calculation-in-pattern-mode.patch
- Update to version 1.2.0
  * General behavior
  - Remembering paths in all export/import/save/open dialogs.
  - Introducing keyboard shortcut for the Open Pattern dialog.
  - Allow for opening more than one Pattern at once.
  - All available audio drivers can now be chosen via CLI.
  - Implement missing EFFECT_LEVEL_RELATIVE MIDI action
  - If the Timeline is activated, the tempo set using the BPM
    widget, BeatCounter, Tap Tempo, or MIDI/OSC commands is used left
    of the first tempo marker.
  - The tempo provided by an external JACK timebase master
    overwrites all internal tempo settings.
  - The BPM widget switches to read-only mode and displays the
    current playback speed when the Timeline is activated.
  - Activation of the Timeline is now stored in each individual
    .h2song file.
  - Autosave files will be hidden. The interval they are stored with
    as well whether there is an autosave at all can be set via the
    Preferences. Hydrogen will inform the user whether there are
    unsaved changes to recover taken from the autosave file.
  - Hydrogen is now able to recover changes applied to a new and
    empty song in case they are discarded or the session end
    untimely (using autosave files)
  - Multiple actions can be assigned to a single MIDI event.
  - The virtual keyboard is now decoupled from the "Hear New Notes"
    button in the Pattern Editor and can be used to play back notes in
    song mode with playback rolling too.
  - Mutable warning dialogs are shown when saving/exporting a
    drumkit containing samples of mismatching license and when
    saving/exporting a drumkit or song containing a copyleft license
    or one requiring an attribution.
  - Drumkit properties dialog does now feature a table listing all
    contained samples and associated licenses.
  - All actions accessible via right-clicking in the SoundLibrary do
    affect the stack drumkits and not the instrument list of the
    current song.
  - All actions accessible via the Drumkits tab of the main menu do
    affect the loaded drumkit using the current song's custom
    instrument and component list.
  * Interface
  - Improved scalability (most PNG images were replaced by SVGs,
    hardcoded PNG labels are now directly drawn by Qt, and spin boxes,
    buttons, and combo boxes are now based on native Qt widgets)
  - Improved internationalization (all labels are translatable now
    and support UTF-8)
  - Improved accessibility (widgets were increased to fill available
    space, preference option to (de- and) increase font size)
  - All colors can be altered via the preferences
  - Input widgets (rotary, fader, combo box, spin box, button) do
    support both mouse and keyboard input (e.g. setting numerical values)
  - Input widgets are faintly highlighted when hovered and more
    strongly highlighted when clicked (focuses). Only the focused
    widget can receive keyboard input
  - MIDI-learnable widgets now show their corresponding MIDI action
    and it's binding in the tooltip
  - It's now possible to jump to the beginning of the currently
    playing pattern by clicking its position on the ruler in the
    pattern editor.
  - The length of patterns can now be changed while transport is
    rolling.
  * PreferencesDialog > Appearance tab overhaul
  - Drop previous font options in favor for three different
    levels of font (without exposing their point sizes)
  - Ability to decrease or increase the overall font size
  - All settings in the Appearance tab - except the overall layout
    and the scaling policy - take effect immediately (no restart
    required anymore)
  - Drop the "fixed" coloring methods and rename "steps" to
    "Custom".
  - Via a colored button the particular line color can now be
    adjusted using a QColorDialog
  - Custom color tab to alter all colors in the GUI (big thanks to
    the Muse4 team for the original code).
  - All options set in the Appearance tab can be imported and
    exported into and shared via dedicated .h2theme files.
  - Overhauled MIDI Table
  - Per effect or layer setting are now done in dedicated spin
    boxes instead of providing individual actions for each.
  - Only spin boxes for parameters required for a particular
    action are shown.
  - Rows can be removed by unsetting both the Event and Action
    combo box.
  - Clicking the widget showing the status messages does now open a
    dropdown menu displaying the last 100 messages.
  * Audio processing
  - Set CoreAudio (macOS) buffer size to control latency
  - New fast exponential ADSR envelope processing
  * InstrumentEditor UX improvements:
  - rework start/end/loop frame slider selection and motion.
  - rework velocity/pan envelope editing
  * SongEditor UX improvements:
  - Tags can now be inserted at all possible columns
  - Hovering a Tag displays its content
  - Changed behavior of the Tempo Marker dialog: When clicking an
    existing Tempo Marker it can be moved, edited, or
    deleted. Clicking a column with no Tempo Marker present allows
    to create a new one at an arbitrary location.
  - Timeline is deactivated automatically when switching to Pattern
    Mode or a JACK timebase master is present
  - The tempo used left of the first tempo marker is painted in a
    darker color.
  - The currently used Tempo Marker gets highlighted.
  - Tags have been moved into Timeline (next to the Tempo Markers)
    in order to make room to accommodate the cursor in the ruler to
    highlight the current position
  - Tags can be inserted by left-clicking the bottom area of the
    Timeline (above the ruler).
  - Clicking the ruler is now always enabled and automatically
    switches transport into Song Mode.
  - Full-size playhead
  - The icons in the pattern list indicating whether a pattern is
    playing in stacked pattern mode are now colored and can have four
    different states: on, off, off next (pattern is played till the
    end and then turned off), and on next (pattern is played as soon
    as transport is looped again)
  - In song mode the pattern editor can be locked meaning that
    always the bottom-most pattern of the current column the
    playhead resides in as well as all other playing notes are
    shown. Pattern selection is done automatically when moving into
    a different column.
  * PatternEditor UX tweaks:
  - Relocating transport by clicking the ruler is now supported
    (like in the SongEditor) and automatically switches transport
    into Pattern Mode.
  - Full-size playhead
  - The ruler was decoupled from the currently selected pattern. It
    always has the size of the largest playing pattern and always
    shows the transport position using a playhead. Whether or not the
    current pattern is played back is indicated by a full-height
    cursor.
  - All note properties except of the note key can now be altered in
    both the drum pattern editor and the piano roll editor by
    right-clicking and dragging a note.
  - All notes of the currently playing patterns will be hinted in
    stacked pattern mode, when selecting a virtual pattern, or in
    case the pattern editor is locked in song mode. Even those notes
    exceeding the length of the current pattern are shown.
  * OSC API
  - Add command /Hydrogen/LOAD_DRUMKIT
  - Add command /Hydrogen/UPGRADE_DRUMKIT
  - Add command /Hydrogen/VALIDATE_DRUMKIT
  - Add command /Hydrogen/EXTRACT_DRUMKIT
  - Add command /Hydrogen/BPM
  - /Hydrogen/STRIP_SOLO_TOGGLE/X and /Hydrogen/STRIP_MUTE_TOGGLE/X
    can now be called without any argument too
  * H2CLI
  - Add `--upgrade` option to upgrade a drumkit
  - Add `--check` option to validate a drumkit
  - Add `--extract` option to extract the content of a drumkit
  - Drumkit supplied using `-k` option can now be either the name of
    an install kit or an absolute path to a kit (does not have to be
    located in the Hydrogen's drumkit folder).
  * Bugfixes
  - fix dithering of SongEditor when viewing the playback track
    and resizing the application or for very small size (#1379).
  - fix rewinding to beginning of pattern in pattern mode with no
    pattern inserted in SongEditor (#932)
  - fix display of tags and tempo marker while loading a song
    (introduced in 1.1.0) (#1393)
  - default MIDI driver is now picked with the system's capabilities
    in mind
  - remove unwanted samples at the end of the exported song (to
    .wav) (#946)
  - fix undefined tempo before first tempo marker (#416)
  - fix Song export to keep writing till all notes and FX have faded
    out
  - notes at first ticks in pattern were missed when relocation
    transport using the position ruler
  - fix playhead glitches when adding toggling patterns at the end
    of the song after transport was loop at least once
  - deactivating loop mode result stopping transport at the end of
    the song even if transport was already looped at least once
  - relocation of the playhead use JACK is now also support in case
    transport is not rolling
  - Hydrogen is now able to handle multiple drumkits featuring the
    same name in the SoundLibrary. The drumkit's absolute path will be
    used as unique handler from now on.
  - Mixing instruments from different drumkit in one Song works
    again
  - Hydrogen shows a now a warning dialog when exporting/saving date
    to read-only folders
  - fix text overflow in Director
  * Crash reporting
  - Fatal errors will now show a GUI report including details to report
    and potential hints about the cause
* Sat Jul 23 2022 Dirk Müller <dmueller@suse.com>
- update to 1.1.1:
  * Keyboard cursor-driven pattern, song and note properties editing
  * Note selection and movement in pattern editors
  * New OSC commands (new song, open song, save song (as), quit,
  * toggle looped playback, toggle timeline, toggle Jack transport,
  * toggle Jack timebase master, add/delete timeline marker,
  * toggle song/pattern playback mode)
  * NSM support reworked
  * Deprecating JACK-session
  * Instrument main pitch shift offset
  * Custom pattern size support with representation in note values
  * Custom pan law support in mixer
  * Audio output device selection in CoreAudio (macOS) and PortAudio (Windows)
  * Preferences dialog 'OK' bug
  * Audio problems when using LADSPA plugins with PulseAudio
  * MIDI crashes and other issues on 64-bit Windows
  * Missing tags and markers
  * Inability to control audio latency on Windows (PortAudio)
- add release-version.patch to avoid devel-build warning
- drop fix-version-soversion.patch: this needs to be, if at all
  upstreamed
* Sun May  9 2021 Dirk Müller <dmueller@suse.com>
- update to 1.0.2:
  * User-selectable translation language
  * Bug fixes including critical startup bug on macOS Big Sur
* Sun Nov 15 2020 munix9@googlemail.com
- Update to version 1.0.1
  * Fixed compilation with libtar
  * Fixed jack transport tempo drift when using non-integer bpm values
  * Disabled "development mode" warning
  * Fix crash on saving ladspa settings
  * Added manual + tutorial files to Windows and OS X Installers
- Update to version 1.0.0
  * QT5 support
  * MIDI feedback
  * OSC support (incl. feedback)
  * Playback track
  * Menu redesign
  * Note probability property
  * Velocity automation
  * Full screen mode
  * New default kit: GMRockKit
- Add fix-obsolete-appdata.patch
- Add fix-version-soversion.patch (replaces hydrogen-0.9.6-lib64.patch)
- Remove hydrogen-no-current-time.patch (__DATE__ and __TIME__
  are considered by SOURCE_DATE_EPOCH and the compiler)
- Remove hydrogen-fix-qt5.15.patch (fixed upstream)
- Remove hydrogen-gcc47.patch (obsolete)
- Remove hydrogen-0.9.6-lib64.patch (obsolete)
- h2cli.1 is now created during %%install
- Clean up spec file
* Wed Jun  3 2020 davejplater@gmail.com
- Update to version 0.99+git20200527 and fix factory build against
  qt 5.15 with hydrogen-fix-qt5.15.patch
- Remove incorporated patches:
  hydrogen-ongEditorPanel-clean-up-scroll-signals.patch,
  hydrogen-SongEditorPanel-Add-methods-to-show-Timeline-Playbac.patch
  and hydrogen-SongEditor-Fix-timeline-scrolling.patch
- Upstream changes:
  * Fix buffer and period size calculation
  * hydrogen.cpp: change return value behavior of audioEngine_process()
  * Fix prefs dialog buffersize driver restart message
  * Fail gracefully on failure to set ALSA period (Fix #879)
  * Bugfix for #857: Check audioEngine_process() ret. value when exporting
  * Do not update specific UI parts if song export is active  (see #857)
  * More smaller fixes which address compiler warnings..
  * ExportMidiDialog: initialize pSmfWriter
  * Fix #874 - improve scrolling to newly selected pattern (#875)
* Wed Feb 12 2020 Stefan Dirsch <sndirsch@suse.com>
- hydrogen-ongEditorPanel-clean-up-scroll-signals.patch,
  hydrogen-SongEditorPanel-Add-methods-to-show-Timeline-Playbac.patch,
  hydrogen-SongEditor-Fix-timeline-scrolling.patch,
  * adjusted git commits from upstream, which fix scrolling in
    Song Editor (boo#1163519)
* Sun Apr  7 2019 plater <davejplater@gmail.com>
- Update to 1.0.0-beta named version 0.9.9pre1
- Now builds with qt5
- Rebased hydrogen-0.9.6-lib64.patch, hydrogen-gcc47.patch and
  hydrogen-no-current-time.patch.
- Removed hydrogen-0.9.6-desktop.patch.
* Wed Mar  7 2018 davejplater@gmail.com
- Remove lash dependency and enable pulse audio support.
* Wed Apr 12 2017 davejplater@gmail.com
- Modified hydrogen-no-current-time.patch to remove all references
  to current date and time.
* Wed Jan 25 2017 jengelh@inai.de
- Trim description and fix all the incomplete sentences.
* Thu Jan 12 2017 wbauer@tmo.at
- Update to version 0.9.7, adapt patches
- Drop hydrogen.1 source file, move the included man page to the
  right place instead of installing our own version
- Updated h2cli.1 man page
- Use desktop-file-utils macros instead of update-desktop-database
- Upstream changes:
  * The color of the SongEditors squares is now configurable
  * Added support for midi cymbal choking
  * Added support for midi hihat pressure control
  * Added hihat pressure groups
  * Added basic non session manager support
  * Added instrument components
  * Basic lilypond export
  * New windows cross compilation script
  * Support for soundlibrary images
  * Configurable sample selection algorithm
  * Support for soundlibraries with images
  * New midi action:
  * SELECT_PREV_PATTERN_RELATIVE
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashisms in post/postun scripts
* Fri Sep  5 2014 wbauer@tmo.at
- Update to final version 0.9.6, adapt patches
- Changed hydrogen-0.9.6-desktop.patch to not add quotes to the
  german Name and GenericName entries in the .desktop file, this
  doesn't really make sense and looks bad in the application menu
- Updated h2cli.1 and hydrogen.1 man pages
- Upstream changes (compared to 0.9.5):
  * Release 0.9.6
  * new build system (cmake)
  * add undo for song/pattern editor
  * jack-session support
  * jack-midi support
  * several bug fixes
  * tabbed interface
  * several small changes to the GUI
  * improve ExportSong add use of TimeLineBPM,
    RubberbandBatch processor and different types of resample interpolation
* Sat Nov 23 2013 wbauer@tmo.at
- Update to version 0.9.6-beta3, adapt patches
- Upstream changes:
  * Release 0.9.6
  * new build system (cmake)
  * add undo for song/pattern editor
  * jack-session support
  * jack-midi support
  * several bug fixes
  * tabbed interface
  * several small changes to the GUI
  * improve ExportSong add use of TimeLineBPM,
    RubberbandBatch processor and different types of resample interpolation
* Sun Jun  2 2013 andreas.stieger@gmx.de
- remove build requirements subversion and rsync
* Sat Mar 17 2012 boris@steki.net
- Add hydrogen-gcc47.patch: Fix build with gcc 4.7.
* Tue Oct 25 2011 coolo@suse.com
- fix another link into %%buildroot
* Fri Oct 14 2011 davejplater@gmail.com
- Changed build to release due to the default debug build being
  sluggish.
* Tue Oct 11 2011 davejplater@gmail.com
- Gave libhydrogen-core.so a SONAME and fixed the <= 11.4 build
  which needed Qt webkit to have QtXmlPatterns with
  BuildRequires: pkgconfig(QtXmlPatterns)
* Wed Oct  5 2011 davejplater@gmail.com
- Update to version 0.9.6, all patches obsolete, remade
  hydrogen-no-current-time.patch & hydrogen-0.9.6-desktopfile.patch
- Build system now uses cmake, rewrote the Build section and added
  man page for h2cli. Created devel and libhydrogen-core-0_9_6-0
  sub packages.
- Upstream changes :
  * Release 0.9.6
  * new build system (cmake)
  * add undo for song/pattern editor
  * jack-session support
  * some bug fixes
* Sun Aug 14 2011 ro@suse.de
- make it build even if python reports platform as linux3
* Fri Mar 18 2011 davejplater@gmail.com
- Update to Version 0.9.5 added portaudio.patch from upstream.
- Made hydrogen-no-current-time.patch use __TIMESTAMP__ instead of
  __DATE__
- No more kde3 dependency since version 0.9.4, now uses Qt4.
- Added man page created with hepl2man.
- Added hydrogen-0.9.5-desktopfile.patch which replaces
  linux/hydrogen.desktop file which is installed with the one in
  the top source directory.
- Upstream changes :
  * load playlists at startup
  * midi-learn works now with shift-click on some gui elements
  * multi-track export and LADI support
  * maximum number of bars is now configurable
  * added czech translation
  * fixed serveral export song failures
  * added ogg, flac, aiff export support
  * added some new commandline parameter for no_gui version
  * added rubberband-cli support
  * several improvements on sample editor
  * added support for app bundles on OSX
  * non destructive sample editor
  * piano roll editor and instrument midi out
  * destructive midi recording and added czech translation
  * support for midi "note off" messages & virtual patterns
  * time line to change song tempo and add tags
  * director and at least several small changes
  * Xml handling is now done by QtXml instead of TinyXML
  * improved support for non-ascii filenames / strings
  * remove direct dependencies to libflac
- For earlier 0.9.4 changes see ChangeLog
* Fri Mar 26 2010 coolo@novell.com
- disable parallel make to avoid the random failures we see
* Mon May 18 2009 tiwai@suse.de
- fix build with gcc 4.4; add missing stdio.h inclusions
* Mon Oct 22 2007 tiwai@suse.de
- fix build with gcc 4.3
* Mon Jun  4 2007 dmueller@suse.de
- remove FLAC 1.1.4 patch for < 10.3
* Mon May  7 2007 stbinner@suse.de
- fix build on < 10.3
* Thu May  3 2007 wstephenson@suse.de
- fix buildrequires: libraptor1-devel -> libraptor-devel
* Thu May  3 2007 lrupp@suse.de
- fix buildrequires: raptor-devel -> libraptor1-devel
* Mon Apr 16 2007 tiwai@suse.de
- fix build with FLAC 1.1.4.
* Thu Jan 18 2007 tiwai@suse.de
- use RPM_OPT_FLAGS for plugins.
* Mon Jul 31 2006 tiwai@suse.de
- updated to version 0.9.3:
  * mostly bugfixes, including memory leak (#194576)
  * new plugins
* Thu Jun 15 2006 dmueller@suse.de
- build parallel
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct 18 2005 tiwai@suse.de
- fixed for gcc 4.1.
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Wed Jul 27 2005 tiwai@suse.de
- updated to version 0.9.2.
* Wed May 11 2005 schwab@suse.de
- Fix library order.
- Fix broken cast.
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 0.9.1.
* Thu Dec 16 2004 coolo@suse.de
- tried to fix Makefiles, but disabled unsermake in the middle
* Wed Aug 25 2004 mana@suse.de
- update to 0.8.2 (non-beta)
* Mon Aug 16 2004 ro@suse.de
- run update_admin
* Tue Mar  2 2004 tiwai@suse.de
- updated to version 0.8.2beta1.
* Fri Feb 20 2004 tiwai@suse.de
- fixed the installation of desktop file.
* Wed Jan 14 2004 tiwai@suse.de
- updated to version 0.8.1.
  libhydrogen is merged again.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Sep 19 2003 tiwai@suse.de
- fixed the desktop icon path.
* Mon Sep 15 2003 tiwai@suse.de
- added desktop icons.
* Fri Aug 29 2003 tiwai@suse.de
- added %%run_ldconfig.
- fixed categories.
* Thu Aug 28 2003 tiwai@suse.de
- fixed the change of types in the recent JACK.
* Thu Aug 14 2003 tiwai@suse.de
- added desktop file.
* Mon Jul  7 2003 tiwai@suse.de
- updated to version 0.8.0.
* Tue Apr  1 2003 tiwai@suse.de
- initial version: 0.7.6.
